<?php

error_reporting(E_ALL);

include 'ApMailer.php';

function param($name, $default = NULL) {
    return isset($_REQUEST[$name]) ? $_REQUEST[$name] : $default;
}

function html($data) {
    return htmlentities($data);
}

$errors   = [];
$messages = [];

$config = [
    'defaultFrom' => 'mymail@example.org',  // Адрес, который будет подставляться в поле "От"
    'onError'     => function($error) use (&$errors) { $errors[] = $error; },
    'afterSend'   => function($text) use (&$messages) { $messages[] = $text; },
    'transports'  => [
//      ['file', 'dir'  => 'mails'],  // Сохранять письма в папке
        [
            'smtp', 
            'login'    => '****@yandex.ru',  // Логин
            'password' => '******',          // Пароль
            'host'     => 'smtp.yandex.ru',  // SMTP-сервер
            'ssl'      => 'true',            // Использовать SSL-шифрование
            'port'     => '465',             // Порт подключения
        ],
    ],
];

$messageTo      = 'my.email@example.org';
$messageReplyTo = param('reply-to'   , 'another-mail@example.org');
$messageSubject = param('subject'    , 'Re: очень важная новость');
$messageText    = param('text'       , '<p>Дорогой друг,</p><p>Спешу поделиться радостным известием, к нам едет ревизор!</p>');

if (param('send')) {
    Mailer()->init($config);
    
    $message = Mailer()->newHtmlMessage();
    
    if ($messageSubject) {
        $message->setSubject($messageSubject);
    }
    
    if ($messageTo) {
        $message->addRecipient($messageTo);
    }
    
    if ($messageReplyTo) {
        $message->addReplyTo($messageReplyTo);
    }
    
    $message->addContent(file_get_contents('mail-header.html'));
    $message->addContent($messageText);
    $message->addContent(file_get_contents('mail-footer.html'));
    
    // Если в письме есть картинки, которые должны показываться как картинки,
    // то их надо добавить так:
    // $message->addRelatedFile('signature.png');
    
    if (isset($_FILES['attachment']['size']) && $_FILES['attachment']['size'] > 0) {
        $message->addAttachmentFile(
            $_FILES['attachment']['tmp_name'], 
            $_FILES['attachment']['name'], 
            $_FILES['attachment']['type']
        );
    }
    
    Mailer()->sendMessage($message);
}

?>
<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <title>Написать письмо</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
    <script src="https://code.jquery.com/jquery-3.4.1.slim.js" crossorigin="anonymous"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" crossorigin="anonymous"></script>
    <script src="https://cdn.tinymce.com/4/tinymce.min.js" crossorigin="anonymous"></script>
    <script type="text/javascript">
tinymce.init({
  selector: 'textarea',
  menubar: false,
  browser_spellcheck: true,
  plugins: [
    'advlist autolink lists link image charmap print preview anchor',
    'searchreplace visualblocks code fullscreen',
    'insertdatetime table contextmenu paste code'
  ],
  toolbar: 'undo redo | insert | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image',
});
</script>
  </head>
<body>
  <div class="container">
    <h1>Написать письмо</h1>
    <form action="" method="post" enctype="multipart/form-data">
    
<?php foreach ($messages as $text) {?>
<div class="alert alert-info">
  <button type="button" class="close" data-dismiss="alert" aria-label="Close">
    <span aria-hidden="true">&times;</span>
  </button>
  <div><?php echo $text?></div>
</div>
<?php }?>

<?php foreach ($errors as $text) {?>
<div class="alert alert-danger">
  <button type="button" class="close" data-dismiss="alert" aria-label="Close">
    <span aria-hidden="true">&times;</span>
  </button>
  <div><?php echo $text?></div>
</div>
<?php }?>
      
      <fieldset>
        <legend>Письмо</legend>

        <div class="form-group row">
          <label class="col-2 col-form-label">Адрес для ответа (Reply-To)</label>
          <div class="col-10">
            <input class="form-control" type="text" name="reply-to" value="<?=html($messageReplyTo)?>">
          </div>
        </div>
        
        <div class="form-group row">
          <label class="col-2 col-form-label">Тема сообщения</label>
          <div class="col-10">
            <input class="form-control" type="text" name="subject" value="<?=html($messageSubject)?>">
          </div>
        </div>
        
        <div class="form-group row">
          <label class="col-2 col-form-label">Текст сообщения</label>
          <div class="col-10">
            <textarea class="form-control" name="text" rows="10"><?=html($messageText)?></textarea>
          </div>
        </div>
        
        <div class="form-group row">
          <label class="col-2 col-form-label">Вложить файл</label>
          <div class="col-10">
            <input class="form-control-file" type="file" name="attachment">
          </div>
        </div>
        
        <div class="form-group row">
          <label class="col-2 col-form-label"></label>
          <div class="col-10">
            <input class="btn btn-primary" type="submit" name="send" value="Отправить">
          </div>
        </div>
        
      </fieldset>
    </form>
  </div>
</body>
</html>